pub struct PackageIndexIteratorProxy { /* private fields */ }Implementations
Sourceimpl PackageIndexIteratorProxy
impl PackageIndexIteratorProxy
Sourcepub fn take_event_stream(&self) -> PackageIndexIteratorEventStream
pub fn take_event_stream(&self) -> PackageIndexIteratorEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn next(
&self,
) -> QueryResponseFut<Vec<PackageIndexEntry>, FDomainResourceDialect>
pub fn next( &self, ) -> QueryResponseFut<Vec<PackageIndexEntry>, FDomainResourceDialect>
Returns the next chunk of package index entries. When the iterator is exhausted, this returns an empty vector.
- response
entriesthe next chunk of entries in the package index.