pub struct RepositoryIteratorProxy { /* private fields */ }Implementations
Sourceimpl RepositoryIteratorProxy
impl RepositoryIteratorProxy
Sourcepub fn take_event_stream(&self) -> RepositoryIteratorEventStream
pub fn take_event_stream(&self) -> RepositoryIteratorEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn next(
&self,
) -> QueryResponseFut<Vec<RepositoryConfig>, FDomainResourceDialect>
pub fn next( &self, ) -> QueryResponseFut<Vec<RepositoryConfig>, FDomainResourceDialect>
Advances the iterator and returns the next batch of repositories.
- response
reposa vector ofRepositoryConfigrepositories. Will return an empty vector when there are no more repositories.